MessageRole enum

Message role for conversation turns.

Used to tag messages in conversation history with their source.

Inheritance
Available extensions

Values

system → const MessageRole

System prompt that defines assistant behavior. Persists across ConversationContext.clear calls.

user → const MessageRole

User message.

assistant → const MessageRole

Assistant response.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFfi() → FfiMessageRole
Convert to the FFI enum.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromFfi(FfiMessageRole ffi) MessageRole
Convert from the FFI enum.

Constants

values → const List<MessageRole>
A constant List of the values in this enum, in order of their declaration.