RunOptions class

Per-run controls for SDK execution.

Constructors

RunOptions({AbortPolicy abortPolicy = const AbortPolicy(), String? cloudProvider, String? cloudModel, String? cloudGatewayUrl, String? correlationId, int? maxGraceTokens})
const
RunOptions.cloudFallback({AbortPolicy abortPolicy = const AbortPolicy.cloudFallback(), String? cloudProvider, String? cloudModel, String? cloudGatewayUrl, String? correlationId, int? maxGraceTokens})
Enable local streaming abort with authenticated cloud fallback.
const

Properties

abortPolicy AbortPolicy
final
cloudGatewayUrl String?
final
cloudModel String?
final
cloudProvider String?
final
correlationId String?
final
hashCode int
The hash code for this object.
no setterinherited
maxGraceTokens int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFfi() → FfiRunOptions
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited