ThermalState enum

Thermal pressure classification matching the desktop pollers' Celsius bands (Normal < 60, Warm 60–70, Hot 70–80, Critical >= 80).

Inheritance
Available extensions

Values

normal → const ThermalState
warm → const ThermalState
hot → const ThermalState
critical → const ThermalState

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ThermalState>
A constant List of the values in this enum, in order of their declaration.