LoadProgress class

Download progress update (0.0 to 1.0).

Inheritance

Constructors

LoadProgress(double progress)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
percentage int
Progress as a percentage (0-100).
no setter
progress double
Progress value from 0.0 to 1.0
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited