XybridModelLoader class
Prepares a model for loading from registry or local bundle.
Constructors
- XybridModelLoader.fromBundle(String path)
-
Create a loader for a model from a local bundle path.
factory
- XybridModelLoader.fromDirectory(String path)
-
Create a loader for a model from a local directory path.
factory
- XybridModelLoader.fromHuggingFace(String repo)
-
Create a loader for a model from a HuggingFace Hub repository.
factory
- XybridModelLoader.fromRegistry(String modelId)
-
Create a loader for a model from the Xybrid registry.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
load(
) → Future< XybridModel> - Load the model asynchronously.
-
loadWithProgress(
) → Stream< LoadEvent> - Load the model with download progress updates.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited